pilot.filemanagement.gs_adaptor.GSFileAdaptor

Package pilot :: Package filemanagement :: Module gs_adaptor :: Class GSFileAdaptor |

# Class GSFileAdaptor

source code

BigData File Management for Pilot Data

Instance Methods
__init__(self, service_url, security_context=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
get_security_context(self) Returns security context that needs to be available on the distributed node in order to access this Pilot Data | source code
initialize_pilotdata(self) | source code
get_pilotdata_size(self) | source code
delete_pilotdata(self) | source code
get_state(self) | source code
create_du(self, du_id) | source code
put_du(self, du) | source code
copy_du(self, du, pd_new) | source code
get_du(self, du, target_url) | source code
remove_du(self, du) | source code
transfer(self, source_url, target_url) | source code
create_remote_directory(self, target_url) | source code
get_path(self, target_url) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, service_url, security_context=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)